@@ -1,5 +1,8 @@
 package Test::Run::Base::Struct;
 
+use strict;
+use warnings;
+
 =head1 NAME
 
 Test::Run::Base::Struct - base class for Test::Run's "structs", that are
@@ -109,6 +112,8 @@ L<Test::Run::Base>, L<Test::Run::Obj>, L<Test::Run::Core>
 
 This file is freely distributable under the MIT X11 license.
 
+L<http://www.opensource.org/licenses/mit-license.php>
+
 =head1 AUTHOR
 
 Shlomi Fish, L<http://www.shlomifish.org/>.
