@@ -99,6 +99,12 @@ sub _assign_canon_strings
     );
 }
 
+=head2 $self->first_canon_string()
+
+The first of the canon_strings(). (With index 0).
+
+=cut
+
 sub first_canon_string
 {
     my $self = shift;
@@ -106,6 +112,12 @@ sub first_canon_string
     return $self->canon_strings()->[0];
 }
 
+=head2 $self->rest_of_canons()
+
+An array reference containing all the canons except the 0th.
+
+=cut
+
 sub rest_of_canons
 {
     my $self = shift;
